@@ -69,7 +69,7 @@ use Scalar::Util ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.04';
+	$VERSION = '1.05';
 }
 
 
@@ -94,7 +94,7 @@ in an object.
 sub new {
 	my $class  = ref $_[0] ? ref shift : shift;
 	my $object = Scalar::Util::blessed($_[0]) ? shift : return undef;
-	bless { OBJECT => $object }, $class;
+	return bless { OBJECT => $object }, $class;
 }
 
 
@@ -138,7 +138,7 @@ For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -146,7 +146,8 @@ L<Class::Adapter::Clear>, L<Class::Adapter::Builder>, L<Class::Decorator>
 
 =head1 COPYRIGHT
 
-Copyright 2005 Adam Kennedy.
+Copyright 2005 - 2008 Adam Kennedy.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
